# Setux Actions

[Setux] Actions

[PyPI] - [Repo] - [Doc]


[PyPI]: https://pypi.org/project/setux_actions
[Repo]: https://notabug.org/dugres/setux_actions
[Doc]: https://setux-actions.readthedocs.io/en/latest
[Setux]: https://setux.readthedocs.io/en/latest
